%global _hardened_build 1
 
Name:           sddm 
Version:        0.18.1
Release:        34%{?dist}
License:        GPLv2+
Summary:        QML based X11 desktop manager

Url:            https://github.com/sddm/sddm
Source0:        https://github.com/sddm/sddm/archive/%{name}-%{version}.tar.gz

## upstream patches (in lookaside cache)

## upstreamable patches
# Fixes RHBZ #1392654
#Patch54: https://github.com/sddm/sddm/pull/735.patch

# Shamelessly stolen from gdm
Source11:       sddm.pam
# Shamelessly stolen from gdm
Source12:       sddm-autologin.pam
# systemd tmpfiles support for /var/run/sddm
Source13:       tmpfiles-sddm.conf
# sample sddm.conf generated with sddm --example-config, and entries commented-out
Source14: sddm.conf
# README.scripts
Source15: README.scripts
# sysconfig snippet
Source16: sddm.sysconfig

Provides: service(graphical-login) = sddm

BuildRequires:  cmake >= 2.8.8
BuildRequires:  extra-cmake-modules
BuildRequires:  libxcb-devel
BuildRequires:  pam-devel
BuildRequires:  libstatgrab-devel
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
# sometimes python-docutils, sometimes python2-docutils, sometimes python3-docutils.
# use path then for sanity
BuildRequires:  /usr/bin/rst2man
BuildRequires:  qt5-qtbase-devel >= 5.6
BuildRequires:  qt5-qtdeclarative-devel >= 5.6
BuildRequires:  qt5-qttools-devel >= 5.6
# verify presence to pull defaults from /etc/login.defs
BuildRequires:  shadow-utils
BuildRequires:  systemd

Obsoletes: kde-settings-sddm < 20-5

%if 0%{?fedora}
# for /usr/share/backgrounds/default.png
BuildRequires: nde-backgrounds
BuildRequires: GraphicsMagick
#Requires: nde-backgrounds
# for /usr/share/pixmaps/system-logo-white.png
Requires: system-logos
%endif
Requires: systemd
Requires: xorg-x11-xinit
Requires: libstatgrab
%ifnarch s390 s390x
Requires: xorg-x11-server-Xorg

Suggests: qt5-qtvirtualkeyboard%{?_isa}
%endif
%{?systemd_requires}

Requires(pre): shadow-utils

%description
SDDM is a modern display manager for X11 aiming to be fast, simple and
beautiful. It uses modern technologies like QtQuick, which in turn gives the
designer the ability to create smooth, animated user interfaces.

%package themes
Summary: SDDM Themes
# for upgrade path
Obsoletes: sddm < 0.2.0-0.12
Requires: %{name} = %{version}-%{release}
BuildArch: noarch
%description themes
A collection of sddm themes, including: elarun, maldives, maya


%prep
%setup -q

%if 0%{?fedora}
#FIXME/TODO: use version on filesystem instead of using a bundled copy
cp -v /usr/share/backgrounds/default.png  \
      src/greeter/theme/background.png
ls -sh src/greeter/theme/background.png
gm mogrify -resize 1920x1200 src/greeter/theme/background.png
ls -sh src/greeter/theme/background.png
%endif


%build
mkdir %{_target_platform}
pushd %{_target_platform}
%{cmake} .. \
  -DBUILD_MAN_PAGES:BOOL=ON \
  -DCMAKE_BUILD_TYPE:STRING="Release" \
  -DENABLE_JOURNALD:BOOL=ON \
  -DSESSION_COMMAND:PATH=/etc/X11/xinit/Xsession \
  -DWAYLAND_SESSION_COMMAND:PATH=/etc/sddm/wayland-session
popd

%make_build -C %{_target_platform}/%{_target_platform}


%install
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}/%{_target_platform}

install -Dpm 644 %{SOURCE11} %{buildroot}%{_sysconfdir}/pam.d/sddm
install -Dpm 644 %{SOURCE12} %{buildroot}%{_sysconfdir}/pam.d/sddm-autologin
install -Dpm 644 %{SOURCE13} %{buildroot}%{_tmpfilesdir}/sddm.conf
install -Dpm 644 %{SOURCE14} %{buildroot}%{_sysconfdir}/sddm.conf
install -Dpm 644 %{SOURCE15} %{buildroot}%{_datadir}/sddm/scripts/README.scripts
install -Dpm 644 %{SOURCE16} %{buildroot}%{_sysconfdir}/sysconfig/sddm
mkdir -p %{buildroot}%{_localstatedir}/run/sddm
mkdir -p %{buildroot}%{_localstatedir}/lib/sddm
mkdir -p %{buildroot}%{_sysconfdir}/sddm/
mkdir -p %{buildroot}/etc/rc.d/init.d/
cp -a %{buildroot}%{_datadir}/sddm/scripts/* \
      %{buildroot}%{_sysconfdir}/sddm/
cp -a %{buildroot}%{_datadir}/sddm/scripts/uds-ssoservice \
      %{buildroot}/etc/rc.d/init.d/
# we're using /etc/X11/xinit/Xsession (by default) instead
rm -fv %{buildroot}%{_sysconfdir}/sddm/Xsession


%pre
getent group sddm >/dev/null || groupadd -r sddm
getent passwd sddm >/dev/null || \
    useradd -r -g sddm -d %{_localstatedir}/lib/sddm -s /sbin/nologin \
    -c "Simple Desktop Display Manager" sddm
exit 0

%post
systemctl enable sddm.service
systemctl enable vm-daemon.service
# 判断是否是ZTE版本
. /etc/os-release
echo $VERSION | grep "ZTE" > /dev/null
if [ $? -eq 0 ]; then
    chmod +x /etc/rc.d/init.d/uds-ssoservice
    chkconfig --add uds-ssoservice
fi

%preun
%systemd_preun sddm.service
%systemd_preun vm-daemon.service

%postun
%systemd_postun sddm.service
%systemd_postun vm-daemon.service
if [ "$1" -eq "0" ]; then
    chkconfig --del  uds-ssoservice
fi

%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc README.md CONTRIBUTORS
%dir %{_sysconfdir}/sddm/
%config(noreplace)   %{_sysconfdir}/sddm/*
%config(noreplace)   %{_sysconfdir}/sddm.conf
%config(noreplace)   %{_sysconfdir}/pam.d/sddm
%config(noreplace)   %{_sysconfdir}/pam.d/sddm-autologin
%config(noreplace)   %{_sysconfdir}/pam.d/sddm-greeter
%config(noreplace) %{_sysconfdir}/sysconfig/sddm
# it's under /etc, sure, but it's not a config file -- rex
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.DisplayManager.conf
#%{_sysconfdir}/dbus-1/system.d/org.sddm.greeter.autologin.conf
%{_sysconfdir}/dbus-1/system.d/com.vm.daemon.conf
%{_bindir}/sddm
%{_bindir}/sddm-greeter
%{_bindir}/vm-daemon
%{_bindir}/autologin
%{_bindir}/getToken
%{_bindir}/sddm-udstokenserver
%{_libexecdir}/sddm-helper
%{_tmpfilesdir}/sddm.conf
%attr(0711, root, sddm) %dir %{_localstatedir}/run/sddm
%attr(1770, sddm, sddm) %dir %{_localstatedir}/lib/sddm
%{_unitdir}/sddm.service
%{_unitdir}/vm-daemon.service
%{_qt5_archdatadir}/qml/SddmComponents/
%dir %{_datadir}/sddm
%{_datadir}/sddm/faces/
%{_datadir}/sddm/flags/
%{_datadir}/sddm/scripts/
%dir %{_datadir}/sddm/themes/
# %%lang'ify? they're small, probably not worth it -- rex
%{_datadir}/sddm/translations/
%{_mandir}/man1/sddm.1*
%{_mandir}/man1/sddm-greeter.1*
%{_mandir}/man5/sddm.conf.5*
%{_mandir}/man5/sddm-state.conf.5*
/etc/rc.d/init.d/uds-ssoservice

%files themes
%{_datadir}/sddm/themes/elarun/
%{_datadir}/sddm/themes/maldives/
%{_datadir}/sddm/themes/maya/


%changelog
* Wed Oct 28 2020 Wu Jiaheng <wu.jiaheng@zte.com.cn> - 0.18.1-31
- 切换用户更改重复登录配置

* Wed Jul 22 2020 Wu Shangmin <wu.shangmin@zte.com.cn> - 0.18.1-13
- 添加单点登录功能

* Wed Jul 22 2020 Wu Jiaheng <wu.jiaheng@zte.com.cn> - 0.18.1-12
- 加入判断是否虚拟机

